@@ -11,19 +11,12 @@ class VATINField(forms.MultiValueField):
     hidden_widget = VATINHiddenWidget
 
     def __init__(self, choices=VIES_COUNTRY_CHOICES, *args, **kwargs):
-        # Set 'required' to False on the individual fields, because the
-        # required validation will be handled by MultiValueField, not by those
-        # individual fields.
+        max_length = kwargs.pop('max_length', 14)
         fields = (
-            forms.ChoiceField(required=True, choices=choices),
-            forms.CharField(required=True),
+            forms.ChoiceField(required=False, choices=choices),
+            forms.CharField(required=False, max_length=max_length)
         )
-        for f in fields:
-            f.required = False
         widget = VATINWidget(choices=choices)
-
-        #  Pop 'max_length' if send by ModelForm helper.
-        kwargs.pop('max_length', None)
         super(VATINField, self).__init__(widget=widget, fields=fields, *args, **kwargs)
 
     def compress(self, data_list):
@@ -32,16 +25,23 @@ class VATINField(forms.MultiValueField):
         return None
 
     def clean(self, value):
-        try:
-            vatin = VATIN(*value)
-            if vatin.is_valid():
-                return super(VATINField, self).clean(value)
-            else:
+        if not value or not isinstance(value, (list, tuple)):
+            if not value or not [v for v in value if v not in self.empty_values]:
+                if self.required:
+                    raise ValidationError(self.error_messages['required'], code='required')
+                else:
+                    return self.compress([])
+        else:
+            try:
+                vatin = VATIN(*value)
+                if vatin.is_valid():
+                    return super(VATINField, self).clean(value)
+                else:
+                    raise ValidationError(_('%(value)s is not a valid European VAT.'), code='invalid',
+                                          params={'value': self.compress(value)})
+            except ValueError:
                 raise ValidationError(_('%(value)s is not a valid European VAT.'), code='invalid',
                                       params={'value': self.compress(value)})
-        except ValueError:
-            raise ValidationError(_('%(value)s is not a valid European VAT.'), code='invalid',
-                                  params={'value': self.compress(value)})
 
 
 class VIESField(VATINField):
