@@ -52,11 +52,15 @@ class VATINWidget(forms.MultiWidget):
             try:
                 country, code = value
             except:
-                country = None
+                country = Nonepi
+
+
+
                 code = value
             if country in EMPTY_VALUES:
                 try:
-                    empty, country, code = re.split('([a-zA-Z])', code)
+                    country = code[:2]
+                    code = code[2:]
                 except:
                     pass
             return [country, code]
